She Was Tired Of Being Photoshopped, So Here’s What She Did About It.
Description: You'll love this!
Date: 2014-07-11T15:03:31Z

By Lisa Be

LifeBuzz Staff

1.7Mshares

×

- 1594x906

×

# Want More Positive Stories Like This One?

### Step 1: Like Us!

### Step 2: Join Our Newsletter

I've completed the above steps, don't show me again.

# She Was Tired Of Being Photoshopped, So Here’s What She Did About It.

Advertisement

Grammy Award-winning, singer-songwriter Colbie Caillat released her new EP, Gypsy Heart Side A. Her album’s lead single “Try” makes a powerful statement about beauty ideals.

Like on Facebook

Share this with all of your girlfriends by clicking the Share button below.

Source: ColbieCaillatVEVO

Next Post

Advertisement

1.7Mshares

#### Tell us what you think

### Like Us On Facebook!Close this

×

### Join The LifeBuzz Community

You can also Use Your Email To Sign Up.

Already a member? Login.

### Sign Up For LifeBuzz

### Log In To LifeBuzz

Remember me

Forgot your password?

### Forgot Your Password?

If you forgot your password, use this form and we'll send you an email with your username and a link to reset your password

### Additional Verification Required

QR code here, and other stuff I guess

×

# One More Before You Go?

We have a feeling you're going to love one of these currently trending stories...